Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2012-03-09 04:41:09 +0400
committerCampbell Barton <ideasman42@gmail.com>2012-03-09 04:41:09 +0400
commit4f7bdc59d31e94bc97955c1efeef2a8fce0c8ecd (patch)
tree7e0a36829cf52ff260821ce02716727052b95d32 /source/blender/blenlib/intern/path_util.c
parent27d43f3fd3a6fbda95cdb87e4672fe34f19c2205 (diff)
style cleanup: spelling.
also remove large, duplicate comments from sunsky.h
Diffstat (limited to 'source/blender/blenlib/intern/path_util.c')
-rw-r--r--source/blender/blenlib/intern/path_util.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/blender/blenlib/intern/path_util.c b/source/blender/blenlib/intern/path_util.c
index f2c11f46cd6..a512ac746f9 100644
--- a/source/blender/blenlib/intern/path_util.c
+++ b/source/blender/blenlib/intern/path_util.c
@@ -746,7 +746,7 @@ int BLI_path_cwd(char *path)
if (wasrelative==1) {
char cwd[FILE_MAX]= "";
- BLI_current_working_dir(cwd, sizeof(cwd)); /* incase the full path to the blend isnt used */
+ BLI_current_working_dir(cwd, sizeof(cwd)); /* in case the full path to the blend isnt used */
if (cwd[0] == '\0') {
printf( "Could not get the current working directory - $PWD for an unknown reason.");
@@ -1151,7 +1151,7 @@ char *BLI_get_folder_version(const int id, const int ver, const int do_check)
ok= get_path_system(path, NULL, NULL, NULL, ver);
break;
default:
- path[0]= '\0'; /* incase do_check is false */
+ path[0]= '\0'; /* in case do_check is false */
ok= FALSE;
BLI_assert(!"incorrect ID");
}